==> jc-1.4.0.tar.gz: javax/swing/text/DocumentFilter__24FilterBypass.h <==
// public abstract class javax.swing.text.DocumentFilter$FilterBypass

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a912918886e44132 javax_swing_text_DocumentFilter__24FilterBypass

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_DocumentFilter__24FilterBypass_H_
#define _JC_javax_swing_text_DocumentFilter__24FilterBypass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_text_AttributeSet$object;
struct _jc_javax_swing_text_Document$object;

// Typedefs
typedef struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$sub_refs	_jc_javax_swing_text_DocumentFilter__24FilterBypass$sub_refs;
typedef struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$sub_nonrefs	_jc_javax_swing_text_DocumentFilter__24FilterBypass$sub_nonrefs;
typedef struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$refs	_jc_javax_swing_text_DocumentFilter__24FilterBypass$refs;
typedef struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$nonrefs	_jc_javax_swing_text_DocumentFilter__24FilterBypass$nonrefs;
typedef struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object	_jc_javax_swing_text_DocumentFilter__24FilterBypass$object;

typedef const struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$vmethods	_jc_javax_swing_text_DocumentFilter__24FilterBypass$vmethods;
typedef const struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$vtable	_jc_javax_swing_text_DocumentFilter__24FilterBypass$vtable;
typedef const struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$vtype	_jc_javax_swing_text_DocumentFilter__24FilterBypass$vtype;

// Constructors
extern void _jc_javax_swing_text_DocumentFilter__24FilterBypass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_swing_text_DocumentFilter__24FilterBypass$method$getDocument$4e6440f82a066e79(_jc_env *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *);
extern void _jc_javax_swing_text_DocumentFilter__24FilterBypass$method$insertString$6bfaac1df9da2371(_jc_env *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_javax_swing_text_DocumentFilter__24FilterBypass$method$remove$9a62c1b8a76192b7(_jc_env *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, jint);
extern void _jc_javax_swing_text_DocumentFilter__24FilterBypass$method$replace$f6ac20658529aa30(_jc_env *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, jint, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DocumentFilter__24FilterBypass$method_info$getDocument$4e6440f82a066e79;
extern _jc_method _jc_javax_swing_text_DocumentFilter__24FilterBypass$method_info$insertString$6bfaac1df9da2371;
extern _jc_method _jc_javax_swing_text_DocumentFilter__24FilterBypass$method_info$remove$9a62c1b8a76192b7;
extern _jc_method _jc_javax_swing_text_DocumentFilter__24FilterBypass$method_info$replace$f6ac20658529aa30;

// Virtual methods structure
struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$vmethods {
	struct _jc_object	*(*getDocument$4e6440f82a066e79)(_jc_env *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *);
	void	(*insertString$6bfaac1df9da2371)(_jc_env *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, struct _jc_java_lang_String$object *, struct _jc_object *);
	void	(*remove$9a62c1b8a76192b7)(_jc_env *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, jint);
	void	(*replace$f6ac20658529aa30)(_jc_env *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, jint, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_DocumentFilter__24FilterBypass$vmethods	javax_swing_text_DocumentFilter__24FilterBypass;
};

// Vtype
struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DocumentFilter__24FilterBypass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$refs {
    _jc_javax_swing_text_DocumentFilter__24FilterBypass$sub_refs	javax_swing_text_DocumentFilter__24FilterBypass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_DocumentFilter__24FilterBypass$sub_nonrefs	javax_swing_text_DocumentFilter__24FilterBypass;
};

// Object instance structure
struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object {
	_jc_javax_swing_text_DocumentFilter__24FilterBypass$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DocumentFilter__24FilterBypass$vtype	*vtype;
	_jc_javax_swing_text_DocumentFilter__24FilterBypass$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DocumentFilter__24FilterBypass$vtype _jc_javax_swing_text_DocumentFilter__24FilterBypass$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DocumentFilter__24FilterBypass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DocumentFilter__24FilterBypass$class_object;

#endif	/* _JC_javax_swing_text_DocumentFilter__24FilterBypass_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/DocumentFilter__24FilterBypass.h <==
// public abstract class javax.swing.text.DocumentFilter$FilterBypass

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a912918886e44132 javax_swing_text_DocumentFilter__24FilterBypass

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_text_DocumentFilter__24FilterBypass_H_
#define _JC_javax_swing_text_DocumentFilter__24FilterBypass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_text_AttributeSet$object;
struct _jc_javax_swing_text_Document$object;

// Typedefs
typedef struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$sub_refs	_jc_javax_swing_text_DocumentFilter__24FilterBypass$sub_refs;
typedef struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$sub_nonrefs	_jc_javax_swing_text_DocumentFilter__24FilterBypass$sub_nonrefs;
typedef struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$refs	_jc_javax_swing_text_DocumentFilter__24FilterBypass$refs;
typedef struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$nonrefs	_jc_javax_swing_text_DocumentFilter__24FilterBypass$nonrefs;
typedef struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object	_jc_javax_swing_text_DocumentFilter__24FilterBypass$object;

typedef const struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$vmethods	_jc_javax_swing_text_DocumentFilter__24FilterBypass$vmethods;
typedef const struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$vtable	_jc_javax_swing_text_DocumentFilter__24FilterBypass$vtable;
typedef const struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$vtype	_jc_javax_swing_text_DocumentFilter__24FilterBypass$vtype;

// Constructors
extern void _jc_javax_swing_text_DocumentFilter__24FilterBypass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_swing_text_DocumentFilter__24FilterBypass$method$getDocument$4e6440f82a066e79(_jc_env *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_DocumentFilter__24FilterBypass$method$insertString$6bfaac1df9da2371(_jc_env *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_DocumentFilter__24FilterBypass$method$remove$9a62c1b8a76192b7(_jc_env *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_DocumentFilter__24FilterBypass$method$replace$f6ac20658529aa30(_jc_env *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, jint, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DocumentFilter__24FilterBypass$method_info$getDocument$4e6440f82a066e79;
extern _jc_method _jc_javax_swing_text_DocumentFilter__24FilterBypass$method_info$insertString$6bfaac1df9da2371;
extern _jc_method _jc_javax_swing_text_DocumentFilter__24FilterBypass$method_info$remove$9a62c1b8a76192b7;
extern _jc_method _jc_javax_swing_text_DocumentFilter__24FilterBypass$method_info$replace$f6ac20658529aa30;

// Virtual methods structure
struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$vmethods {
	struct _jc_object	*(*getDocument$4e6440f82a066e79)(_jc_env *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *) _JC_JCNI_ATTR;
	void	(*insertString$6bfaac1df9da2371)(_jc_env *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*remove$9a62c1b8a76192b7)(_jc_env *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, jint) _JC_JCNI_ATTR;
	void	(*replace$f6ac20658529aa30)(_jc_env *, struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object *, jint, jint, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_DocumentFilter__24FilterBypass$vmethods	javax_swing_text_DocumentFilter__24FilterBypass;
};

// Vtype
struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DocumentFilter__24FilterBypass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$refs {
    _jc_javax_swing_text_DocumentFilter__24FilterBypass$sub_refs	javax_swing_text_DocumentFilter__24FilterBypass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_DocumentFilter__24FilterBypass$sub_nonrefs	javax_swing_text_DocumentFilter__24FilterBypass;
};

// Object instance structure
struct _jc_javax_swing_text_DocumentFilter__24FilterBypass$object {
	_jc_javax_swing_text_DocumentFilter__24FilterBypass$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DocumentFilter__24FilterBypass$vtype	*vtype;
	_jc_javax_swing_text_DocumentFilter__24FilterBypass$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DocumentFilter__24FilterBypass$vtype _jc_javax_swing_text_DocumentFilter__24FilterBypass$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DocumentFilter__24FilterBypass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DocumentFilter__24FilterBypass$class_object;

#endif	/* _JC_javax_swing_text_DocumentFilter__24FilterBypass_H_ */
